Class: Aws::GeoPlaces::Types::AccessPoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

Position of the access point represented by longitude and latitude for a vehicle.

Constant Summary collapse

SENSITIVE =
[:position, :primary, :label]

Instance Attribute Summary collapse

Instance Attribute Details

#labelString

A short textual description of the access point, such as "North Entrance".

Returns:

  • (String)


51
52
53
54
55
56
57
58
# File 'lib/aws-sdk-geoplaces/types.rb', line 51

class AccessPoint < Struct.new(
  :position,
  :type,
  :primary,
  :label)
  SENSITIVE = [:position, :primary, :label]
  include Aws::Structure
end

#positionArray<Float>

The position in World Geodetic System (WGS 84) format: [longitude, latitude].

Returns:

  • (Array<Float>)


51
52
53
54
55
56
57
58
# File 'lib/aws-sdk-geoplaces/types.rb', line 51

class AccessPoint < Struct.new(
  :position,
  :type,
  :primary,
  :label)
  SENSITIVE = [:position, :primary, :label]
  include Aws::Structure
end

#primaryBoolean

Set to true for the primary access position when the place has more than one access point.

Returns:

  • (Boolean)


51
52
53
54
55
56
57
58
# File 'lib/aws-sdk-geoplaces/types.rb', line 51

class AccessPoint < Struct.new(
  :position,
  :type,
  :primary,
  :label)
  SENSITIVE = [:position, :primary, :label]
  include Aws::Structure
end

#typeString

The type of access point, indicating its intended use. Only applies to results of type place.

Returns:

  • (String)


51
52
53
54
55
56
57
58
# File 'lib/aws-sdk-geoplaces/types.rb', line 51

class AccessPoint < Struct.new(
  :position,
  :type,
  :primary,
  :label)
  SENSITIVE = [:position, :primary, :label]
  include Aws::Structure
end