Class: Aws::GeoPlaces::Types::Address
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::Address
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
The place address.
Constant Summary collapse
- SENSITIVE =
[:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
Instance Attribute Summary collapse
-
#address_number ⇒ String
The number that identifies an address within a street.
-
#block ⇒ String
Name of the block.
-
#building ⇒ String
The name of the building at the address.
-
#country ⇒ Types::Country
The country component of the address.
-
#district ⇒ String
The district or division of a locality associated with this address.
-
#intersection ⇒ Array<String>
Name of the streets in the intersection.
-
#label ⇒ String
Assembled address value built out of the address components, according to the regional postal rules.
-
#locality ⇒ String
The city or locality of the address.
-
#postal_code ⇒ String
An alphanumeric string included in a postal address to facilitate mail sorting, such as post code, postcode, or ZIP code, for which the result should possess.
-
#region ⇒ Types::Region
The region or state results should be present in.
-
#secondary_address_components ⇒ Array<Types::SecondaryAddressComponent>
Components that correspond to secondary identifiers on an Address.
-
#street ⇒ String
The name of the street results should be present in.
-
#street_components ⇒ Array<Types::StreetComponents>
Components of the street.
-
#sub_block ⇒ String
Name of sub-block.
-
#sub_district ⇒ String
A subdivision of a district.
-
#sub_region ⇒ Types::SubRegion
The sub-region or county for which results should be present in.
Instance Attribute Details
#address_number ⇒ String
The number that identifies an address within a street.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#block ⇒ String
Name of the block. Not available in ap-southeast-1 and
ap-southeast-5 regions for GrabMaps customers.
Example: Sunny Mansion 203 block: 2 Chome
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#building ⇒ String
The name of the building at the address. Not available in
ap-southeast-1 and ap-southeast-5 regions for GrabMaps
customers.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#country ⇒ Types::Country
The country component of the address.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#district ⇒ String
The district or division of a locality associated with this address.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#intersection ⇒ Array<String>
Name of the streets in the intersection. Not available in
ap-southeast-1 and ap-southeast-5 regions for GrabMaps
customers.
Example: ["Friedrichstraße","Unter den Linden"]
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#label ⇒ String
Assembled address value built out of the address components, according to the regional postal rules. This is the correctly formatted address.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#locality ⇒ String
The city or locality of the address.
Example: Vancouver.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#postal_code ⇒ String
An alphanumeric string included in a postal address to facilitate mail sorting, such as post code, postcode, or ZIP code, for which the result should possess.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#region ⇒ Types::Region
The region or state results should be present in.
Example: North Rhine-Westphalia.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#secondary_address_components ⇒ Array<Types::SecondaryAddressComponent>
Components that correspond to secondary identifiers on an Address.
Secondary address components include information such as Suite or
Unit Number, Building, or Floor. Not available in ap-southeast-1
and ap-southeast-5 regions for GrabMaps customers.
Address.SecondaryAddressComponents is available in
the following countries:
AUS, CAN, NZL, USA, PRI
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#street ⇒ String
The name of the street results should be present in.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#street_components ⇒ Array<Types::StreetComponents>
Components of the street. Not available in ap-southeast-1 and
ap-southeast-5 regions for GrabMaps customers.
Example: Yonge from "Yonge street".
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#sub_block ⇒ String
Name of sub-block. Not available in ap-southeast-1 and
ap-southeast-5 regions for GrabMaps customers.
Example: Sunny Mansion 203 sub-block: 4
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#sub_district ⇒ String
A subdivision of a district.
Example: Minden-Lübbecke.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |
#sub_region ⇒ Types::SubRegion
The sub-region or county for which results should be present in.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 208 class Address < Struct.new( :label, :country, :region, :sub_region, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :intersection, :street, :street_components, :address_number, :building, :secondary_address_components) SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building] include Aws::Structure end |