Class: Aws::GeoPlaces::Types::AdminNames

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

The official administrative names for an address component, returned when AddressNamesMode is set to Administrative.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#namesArray<Types::TranslationName>

A list of translation names for the administrative address component, including name variants and translations in available languages.

Returns:



403
404
405
406
407
408
# File 'lib/aws-sdk-geoplaces/types.rb', line 403

class AdminNames < Struct.new(
  :names,
  :preference)
  SENSITIVE = []
  include Aws::Structure
end

#preferenceString

Indicates the preference level of the administrative name. Valid values are Primary and Alternative.

Returns:

  • (String)


403
404
405
406
407
408
# File 'lib/aws-sdk-geoplaces/types.rb', line 403

class AdminNames < Struct.new(
  :names,
  :preference)
  SENSITIVE = []
  include Aws::Structure
end