Class: Aws::GeoPlaces::Types::AutocompleteAddressHighlights

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

Describes how the parts of the response element matched the input query by returning the sections of the response which matched to input query terms.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#address_numberArray<Types::Highlight>

The house number or address results should have.

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#blockArray<Types::Highlight>

Name of the block.

Example: Sunny Mansion 203 block: 2 Chome

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#buildingArray<Types::Highlight>

The name of the building at the address.

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#countryTypes::CountryHighlights

The alpha-2 or alpha-3 character code for the country that the results will be present in.



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#districtArray<Types::Highlight>

The district or division of a city the results should be present in.

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#intersectionArray<Array<Types::Highlight>>

Name of the streets in the intersection. For example: e.g. ["Friedrichstraße","Unter den Linden"]

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#labelArray<Types::Highlight>

Indicates the starting and ending indexes for result items where they are identified to match the input query. This should be used to provide emphasis to output display to make selecting the correct result from a list easier for end users.

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#localityArray<Types::Highlight>

The city or locality results should be present in.

Example: Vancouver.

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#postal_codeArray<Types::Highlight>

An alphanumeric string included in a postal address to facilitate mail sorting, such as post code, postcode, or ZIP code for which the result should possess.

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#regionTypes::RegionHighlights

The region or state results should be to be present in.

Example: North Rhine-Westphalia.



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#streetArray<Types::Highlight>

The name of the street results should be present in.

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#sub_blockArray<Types::Highlight>

Name of sub-block.

Example: Sunny Mansion 203 sub-block: 4

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#sub_districtArray<Types::Highlight>

Indicates the starting and ending index of the title in the text query that match the found title.

Returns:



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end

#sub_regionTypes::SubRegionHighlights

The sub-region or county for which results should be present in.



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/aws-sdk-geoplaces/types.rb', line 488

class AutocompleteAddressHighlights < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :street,
  :block,
  :sub_block,
  :intersection,
  :postal_code,
  :address_number,
  :building)
  SENSITIVE = []
  include Aws::Structure
end