Class: Aws::GeoPlaces::Types::AutocompleteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::AutocompleteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:query_text, :bias_position, :political_view, :key]
Instance Attribute Summary collapse
-
#additional_features ⇒ Array<String>
A list of optional additional parameters that can be requested for each result.
-
#bias_position ⇒ Array<Float>
The position in longitude and latitude that the results should be close to.
-
#filter ⇒ Types::AutocompleteFilter
A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.
-
#intended_use ⇒ String
Indicates if the query results will be persisted in customer infrastructure.
-
#key ⇒ String
Optional: The API key to be used for authorization.
-
#language ⇒ String
A list of [BCP 47][1] compliant language codes for the results to be rendered in.
-
#max_results ⇒ Integer
An optional limit for the number of results returned in a single call.
-
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country.
-
#postal_code_mode ⇒ String
The
PostalCodeModeaffects how postal code results are returned. -
#query_text ⇒ String
The free-form text query to match addresses against.
Instance Attribute Details
#additional_features ⇒ Array<String>
A list of optional additional parameters that can be requested for each result.
679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 679 class AutocompleteRequest < Struct.new( :query_text, :max_results, :bias_position, :filter, :postal_code_mode, :additional_features, :language, :political_view, :intended_use, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#bias_position ⇒ Array<Float>
The position in longitude and latitude that the results should be
close to. Typically, place results returned are ranked higher the
closer they are to this position. Stored in [lng, lat] and in the
WGS 84 format.
BiasPosition, FilterBoundingBox, and FilterCircle
are mutually exclusive.
679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 679 class AutocompleteRequest < Struct.new( :query_text, :max_results, :bias_position, :filter, :postal_code_mode, :additional_features, :language, :political_view, :intended_use, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#filter ⇒ Types::AutocompleteFilter
A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.
679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 679 class AutocompleteRequest < Struct.new( :query_text, :max_results, :bias_position, :filter, :postal_code_mode, :additional_features, :language, :political_view, :intended_use, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#intended_use ⇒ String
Indicates if the query results will be persisted in customer
infrastructure. Defaults to SingleUse (not stored). Currently,
Autocomplete does not support storage of results.
679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 679 class AutocompleteRequest < Struct.new( :query_text, :max_results, :bias_position, :filter, :postal_code_mode, :additional_features, :language, :political_view, :intended_use, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#key ⇒ String
Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.
679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 679 class AutocompleteRequest < Struct.new( :query_text, :max_results, :bias_position, :filter, :postal_code_mode, :additional_features, :language, :political_view, :intended_use, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#language ⇒ String
A list of BCP 47 compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry.
679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 679 class AutocompleteRequest < Struct.new( :query_text, :max_results, :bias_position, :filter, :postal_code_mode, :additional_features, :language, :political_view, :intended_use, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#max_results ⇒ Integer
An optional limit for the number of results returned in a single call.
Default value: 5
679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 679 class AutocompleteRequest < Struct.new( :query_text, :max_results, :bias_position, :filter, :postal_code_mode, :additional_features, :language, :political_view, :intended_use, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country.
The following political views are currently supported:
-
ARG: Argentina's view on the Southern Patagonian Ice Field and Tierra Del Fuego, including the Falkland Islands, South Georgia, and South Sandwich Islands -
EGY: Egypt's view on Bir Tawil -
IND: India's view on Gilgit-Baltistan -
KEN: Kenya's view on the Ilemi Triangle -
MAR: Morocco's view on Western Sahara -
RUS: Russia's view on Crimea -
SDN: Sudan's view on the Halaib Triangle -
SRB: Serbia's view on Kosovo, Vukovar, and Sarengrad Islands -
SUR: Suriname's view on the Courantyne Headwaters and Lawa Headwaters -
SYR: Syria's view on the Golan Heights -
TUR: Turkey's view on Cyprus and Northern Cyprus -
TZA: Tanzania's view on Lake Malawi -
URY: Uruguay's view on Rincon de Artigas -
VNM: Vietnam's view on the Paracel Islands and Spratly Islands
679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 679 class AutocompleteRequest < Struct.new( :query_text, :max_results, :bias_position, :filter, :postal_code_mode, :additional_features, :language, :political_view, :intended_use, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#postal_code_mode ⇒ String
The PostalCodeMode affects how postal code results are returned.
If a postal code spans multiple localities and this value is empty,
partial district or locality information may be returned under a
single postal code result entry. If it's populated with the value
EnumerateSpannedLocalities, all cities in that postal code are
returned. If it's populated with the value
EnumerateSpannedDistricts, all combinations of the postal code
with the corresponding district and city names are returned.
679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 679 class AutocompleteRequest < Struct.new( :query_text, :max_results, :bias_position, :filter, :postal_code_mode, :additional_features, :language, :political_view, :intended_use, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#query_text ⇒ String
The free-form text query to match addresses against. This is usually a partially typed address from an end user in an address box or form.
QueryText, and QueryID are mutually exclusive.
679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 679 class AutocompleteRequest < Struct.new( :query_text, :max_results, :bias_position, :filter, :postal_code_mode, :additional_features, :language, :political_view, :intended_use, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |