Class: Aws::GeoPlaces::Types::GeocodeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:query_text, :bias_position, :political_view, :key]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_featuresArray<String>

A list of optional additional parameters, such as time zone, that can be requested for each result.

Returns:

  • (Array<String>)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#address_names_modeString

Specifies how address names are returned. If not set, the service returns normalized (official) names by default. When set to Matched, address names in the response are based on the input query rather than official names. When set to Administrative, the service returns the official administrative names for address components. Administrative currently applies only to addresses in the United States.

Returns:

  • (String)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#address_translationsArray<String>

Specifies which address components to include translations for. Translations include all name variants and alternative names for the requested fields in all available languages. Valid values are District, Locality, Region, and SubRegion.

Returns:

  • (Array<String>)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#bias_positionArray<Float>

The position, in longitude and latitude, that the results should be close to. Typically, place results returned are ranked higher the closer they are to this position. Stored in [lng, lat] and in the WGS 84 format.

Returns:

  • (Array<Float>)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#filterTypes::GeocodeFilter

A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.



1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#intended_useString

Indicates if the query results will be persisted in customer infrastructure. Defaults to SingleUse (not stored). Not supported in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

When storing Geocode responses, you must set this field to Storage to comply with the terms of service. These requests will be charged at a higher rate. Please review the user agreement and service pricing structure to determine the correct setting for your use case.

Returns:

  • (String)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#keyString

Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.

Returns:

  • (String)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#languageString

A list of BCP 47 compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry.

Returns:

  • (String)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#max_resultsInteger

An optional limit for the number of results returned in a single call.

Default value: 20

Returns:

  • (Integer)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#political_viewString

The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country.

Returns:

  • (String)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#postal_code_modeString

The PostalCodeMode affects how postal code results are returned. If a postal code spans multiple localities and this value is empty, partial district or locality information may be returned under a single postal code result entry. If it's populated with the value EnumerateSpannedLocalities, all cities in that postal code are returned. If it's populated with the value EnumerateSpannedDistricts, all combinations of the postal code with the corresponding district and city names are returned.

Returns:

  • (String)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#query_componentsTypes::GeocodeQueryComponents

A structured free text query allows you to search for places by the name or text representation of specific properties of the place.



1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end

#query_textString

The free-form text query to match addresses against. This is usually a partially typed address from an end user in an address box or form.

Returns:

  • (String)


1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
# File 'lib/aws-sdk-geoplaces/types.rb', line 1348

class GeocodeRequest < Struct.new(
  :query_text,
  :query_components,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :postal_code_mode,
  :address_translations,
  :address_names_mode)
  SENSITIVE = [:query_text, :bias_position, :political_view, :key]
  include Aws::Structure
end