Class: Aws::GeoPlaces::Types::GeocodeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#pricing_bucketString

The pricing bucket for which the query is charged at, or the maximum pricing bucket when the query is charged per item within the query.

For more information on pricing, please visit Amazon Location Service Pricing.

Returns:

  • (String)


1384
1385
1386
1387
1388
1389
# File 'lib/aws-sdk-geoplaces/types.rb', line 1384

class GeocodeResponse < Struct.new(
  :pricing_bucket,
  :result_items)
  SENSITIVE = []
  include Aws::Structure
end

#result_itemsArray<Types::GeocodeResultItem>

List of places or results returned for a query.

Returns:



1384
1385
1386
1387
1388
1389
# File 'lib/aws-sdk-geoplaces/types.rb', line 1384

class GeocodeResponse < Struct.new(
  :pricing_bucket,
  :result_items)
  SENSITIVE = []
  include Aws::Structure
end