Class: Aws::GeoPlaces::Types::GeocodeResultItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

The Geocoded result.

Constant Summary collapse

SENSITIVE =
[:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]

Instance Attribute Summary collapse

Instance Attribute Details

#access_pointsArray<Types::AccessPoint>

Position of the access point in World Geodetic System (WGS 84) format: [longitude, latitude].

Returns:



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#addressTypes::Address

The place's address.

Returns:



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#address_number_correctedBoolean

Boolean indicating if the address provided has been corrected.

Returns:

  • (Boolean)


1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#categoriesArray<Types::Category>

Categories of results that results must belong to.

Returns:



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#distanceInteger

The distance in meters from the QueryPosition.

Returns:

  • (Integer)


1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#estimated_point_addressBoolean

If true, indicates that the coordinates of the position and access points of the point address are estimated.

Returns:

  • (Boolean)


1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#food_typesArray<Types::FoodType>

List of food types offered by this result.

Returns:



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#intersectionsArray<Types::Intersection>

All Intersections that are near the provided address.

Returns:



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#main_addressTypes::RelatedPlace

The main address corresponding to a place of type Secondary Address.

Returns:



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#map_viewArray<Float>

The bounding box enclosing the geometric shape (area or line) that an individual result covers.

The bounding box formed is defined as a set 4 coordinates: [{westward lng}, {southern lat}, {eastward lng}, {northern lat}]

Returns:

  • (Array<Float>)


1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#match_scoresTypes::MatchScoreDetails

Indicates how well the entire input matches the returned. It is equal to 1 if all input tokens are recognized and matched.



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#parsed_queryTypes::GeocodeParsedQuery

Free-form text query.



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#place_idString

The PlaceId of the place result.

Returns:

  • (String)


1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#place_typeString

A PlaceType is a category that the result place must belong to.

Returns:

  • (String)


1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#political_viewString

The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country.

Returns:

  • (String)


1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#positionArray<Float>

The position in World Geodetic System (WGS 84) format: [longitude, latitude].

Returns:

  • (Array<Float>)


1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#postal_code_detailsArray<Types::PostalCodeDetails>

Contains details about the postal code of the place/result.

Returns:



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#secondary_addressesArray<Types::RelatedPlace>

All secondary addresses that are associated with a main address. A secondary address is one that includes secondary designators, such as a Suite or Unit Number, Building, or Floor information.

Coverage for this functionality is available in the following countries: AUS, CAN, NZL, USA, PRI.

Returns:



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#time_zoneTypes::TimeZone

The time zone in which the place is located.

Returns:



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#titleString

The localized display name of this result item based on request parameter language.

Returns:

  • (String)


1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end

#translationsTypes::TranslationDetails

All name translations and alternative names for the requested address fields in all available languages.



1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
# File 'lib/aws-sdk-geoplaces/types.rb', line 1499

class GeocodeResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :access_points,
  :time_zone,
  :political_view,
  :match_scores,
  :parsed_query,
  :intersections,
  :main_address,
  :secondary_addresses,
  :translations,
  :estimated_point_address)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :estimated_point_address]
  include Aws::Structure
end