Class: Aws::GeoPlaces::Types::GetPlaceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]

Instance Attribute Summary collapse

Instance Attribute Details

#access_pointsArray<Types::AccessPoint>

Position of the access point in World Geodetic System (WGS 84) format: [longitude, latitude]. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#access_restrictionsArray<Types::AccessRestriction>

Indicates known access restrictions on a vehicle access point. The index correlates to an access point and indicates if access through this point has some form of restriction. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#addressTypes::Address

The place's address.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#address_number_correctedBoolean

Boolean indicating if the address provided has been corrected. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:

  • (Boolean)


1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#business_chainsArray<Types::BusinessChain>

The Business Chains associated with the place.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#categoriesArray<Types::Category>

Categories of results that results must belong to.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#contactsTypes::Contacts

List of potential contact methods for the result/place. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#cross_referencesArray<Types::CrossReference>

The list of supplier references available for this place. Requires the CrossReferences additional feature to be enabled.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#estimated_point_addressBoolean

If true, indicates that the coordinates of the position and access points of the point address are estimated.

Returns:

  • (Boolean)


1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#food_typesArray<Types::FoodType>

List of food types offered by this result. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#main_addressTypes::RelatedPlace

The main address corresponding to a place of type Secondary Address. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#map_viewArray<Float>

The bounding box enclosing the geometric shape (area or line) that an individual result covers.

The bounding box formed is defined as a set of four coordinates: [{westward lng}, {southern lat}, {eastward lng}, {northern lat}]

Returns:

  • (Array<Float>)


1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#opening_hoursArray<Types::OpeningHours>

List of opening hours objects. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#phonemesTypes::PhonemeDetails

How the various components of the result's address are pronounced in various languages. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#place_attributesArray<String>

A list of place attributes for the result, such as whether the business offers drive-through service.

Returns:

  • (Array<String>)


1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#place_idString

The PlaceId of the place you wish to receive the information for.

Returns:

  • (String)


1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#place_typeString

A PlaceType is a category that the result place must belong to.

Returns:

  • (String)


1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#political_viewString

The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:

  • (String)


1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#positionArray<Float>

The position in World Geodetic System (WGS 84) format: [longitude, latitude].

Returns:

  • (Array<Float>)


1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#postal_code_detailsArray<Types::PostalCodeDetails>

Contains details about the postal code of the place/result. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#pricing_bucketString

The pricing bucket for which the query is charged at.

For more information on pricing, please visit Amazon Location Service Pricing.

Returns:

  • (String)


1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#secondary_addressesArray<Types::RelatedPlace>

All secondary addresses that are associated with a main address. A secondary address is one that includes secondary designators, such as a Suite or Unit Number, Building, or Floor information. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Coverage for this functionality is available in the following countries: AUS, CAN, NZL, USA, PRI.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#time_zoneTypes::TimeZone

The time zone in which the place is located.

Returns:



1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end

#titleString

The localized display name of this result item based on request parameter language.

Returns:

  • (String)


1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
# File 'lib/aws-sdk-geoplaces/types.rb', line 1803

class GetPlaceResponse < Struct.new(
  :place_id,
  :place_type,
  :title,
  :pricing_bucket,
  :address,
  :address_number_corrected,
  :postal_code_details,
  :position,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :main_address,
  :secondary_addresses,
  :place_attributes,
  :estimated_point_address,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :map_view, :political_view, :place_attributes, :estimated_point_address]
  include Aws::Structure
end