Class: Aws::GeoPlaces::Types::OpeningHours
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::OpeningHours
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
List of opening hours objects.
Constant Summary collapse
- SENSITIVE =
[:display, :open_now]
Instance Attribute Summary collapse
-
#categories ⇒ Array<Types::Category>
Categories of results that results must belong too.
-
#components ⇒ Array<Types::OpeningHoursComponents>
Components of the opening hours object.
-
#display ⇒ Array<String>
List of opening hours in the format they are displayed in.
-
#open_now ⇒ Boolean
Boolean which indicates if the result/place is currently open.
Instance Attribute Details
#categories ⇒ Array<Types::Category>
Categories of results that results must belong too.
1971 1972 1973 1974 1975 1976 1977 1978 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1971 class OpeningHours < Struct.new( :display, :open_now, :components, :categories) SENSITIVE = [:display, :open_now] include Aws::Structure end |
#components ⇒ Array<Types::OpeningHoursComponents>
Components of the opening hours object.
1971 1972 1973 1974 1975 1976 1977 1978 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1971 class OpeningHours < Struct.new( :display, :open_now, :components, :categories) SENSITIVE = [:display, :open_now] include Aws::Structure end |
#display ⇒ Array<String>
List of opening hours in the format they are displayed in. This can vary by result and in most cases represents how the result uniquely formats their opening hours.
1971 1972 1973 1974 1975 1976 1977 1978 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1971 class OpeningHours < Struct.new( :display, :open_now, :components, :categories) SENSITIVE = [:display, :open_now] include Aws::Structure end |
#open_now ⇒ Boolean
Boolean which indicates if the result/place is currently open.
1971 1972 1973 1974 1975 1976 1977 1978 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1971 class OpeningHours < Struct.new( :display, :open_now, :components, :categories) SENSITIVE = [:display, :open_now] include Aws::Structure end |