Class: Aws::GeoPlaces::Types::OpeningHoursComponents
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::OpeningHoursComponents
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Components of the opening hours object.
Constant Summary collapse
- SENSITIVE =
[:open_time, :open_duration, :recurrence]
Instance Attribute Summary collapse
-
#open_duration ⇒ String
String which represents the duration of the opening period, such as
"PT12H00M". -
#open_time ⇒ String
String which represents the opening hours, such as
"T070000". -
#recurrence ⇒ String
Days or periods when the provided opening hours are in affect.
Instance Attribute Details
#open_duration ⇒ String
String which represents the duration of the opening period, such as
"PT12H00M".
1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1999 class OpeningHoursComponents < Struct.new( :open_time, :open_duration, :recurrence) SENSITIVE = [:open_time, :open_duration, :recurrence] include Aws::Structure end |
#open_time ⇒ String
String which represents the opening hours, such as "T070000".
1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1999 class OpeningHoursComponents < Struct.new( :open_time, :open_duration, :recurrence) SENSITIVE = [:open_time, :open_duration, :recurrence] include Aws::Structure end |
#recurrence ⇒ String
Days or periods when the provided opening hours are in affect.
Example: FREQ:DAILY;BYDAY:MO,TU,WE,TH,SU
1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1999 class OpeningHoursComponents < Struct.new( :open_time, :open_duration, :recurrence) SENSITIVE = [:open_time, :open_duration, :recurrence] include Aws::Structure end |