Class: Aws::GeoPlaces::Types::PhonemeTranscription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

How to pronounce the various components of the address or place.

Constant Summary collapse

SENSITIVE =
[:value, :preferred]

Instance Attribute Summary collapse

Instance Attribute Details

#languageString

A list of BCP 47 compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry.

Returns:

  • (String)


2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-geoplaces/types.rb', line 2117

class PhonemeTranscription < Struct.new(
  :value,
  :language,
  :preferred)
  SENSITIVE = [:value, :preferred]
  include Aws::Structure
end

#preferredBoolean

Boolean which indicates if it the preferred pronunciation.

Returns:

  • (Boolean)


2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-geoplaces/types.rb', line 2117

class PhonemeTranscription < Struct.new(
  :value,
  :language,
  :preferred)
  SENSITIVE = [:value, :preferred]
  include Aws::Structure
end

#valueString

Value which indicates how to pronounce the value.

Returns:

  • (String)


2117
2118
2119
2120
2121
2122
2123
# File 'lib/aws-sdk-geoplaces/types.rb', line 2117

class PhonemeTranscription < Struct.new(
  :value,
  :language,
  :preferred)
  SENSITIVE = [:value, :preferred]
  include Aws::Structure
end