Class: Aws::GeoPlaces::Types::ReverseGeocodeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:query_position, :query_radius, :political_view, :key, :heading]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_featuresArray<String>

A list of optional additional parameters, such as time zone that can be requested for each result. For GrabMaps customers, ap-southeast-1 and ap-southeast-5 regions support only the TimeZone value.

Returns:

  • (Array<String>)


2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end

#address_names_modeString

Specifies how address names are returned. When set to Administrative, the service returns the official administrative names for address components. Administrative currently applies only to addresses in the United States.

Returns:

  • (String)


2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end

#filterTypes::ReverseGeocodeFilter

A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.



2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end

#headingFloat

The heading in degrees from true north in a navigation context. The heading is measured as the angle clockwise from the North direction.

Example: North is 0 degrees, East is 90 degrees, South is 180 degrees, and West is 270 degrees.

Returns:

  • (Float)


2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end

#intended_useString

Indicates if the query results will be persisted in customer infrastructure. Defaults to SingleUse (not stored).

When storing ReverseGeocode responses, you must set this field to Storage to comply with the terms of service. These requests will be charged at a higher rate. Please review the user agreement and service pricing structure to determine the correct setting for your use case.

Returns:

  • (String)


2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end

#keyString

Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.

Returns:

  • (String)


2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end

#languageString

A list of BCP 47 compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry. For GrabMaps customers, ap-southeast-1 and ap-southeast-5 regions support only the following codes: en, id, km, lo, ms, my, pt, th, tl, vi, zh

Returns:

  • (String)


2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end

#max_resultsInteger

An optional limit for the number of results returned in a single call.

Default value: 1

Returns:

  • (Integer)


2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end

#political_viewString

The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country. Not supported in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:

  • (String)


2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end

#query_positionArray<Float>

The position in World Geodetic System (WGS 84) format: [longitude, latitude] for which you are querying nearby results for. Results closer to the position will be ranked higher then results further away from the position

Returns:

  • (Array<Float>)


2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end

#query_radiusInteger

The maximum distance in meters from the QueryPosition from which a result will be returned. For GrabMaps customers, ap-southeast-1 and ap-southeast-5 regions support only up to a maximum value of 100,000.

Returns:

  • (Integer)


2417
2418
2419
2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
# File 'lib/aws-sdk-geoplaces/types.rb', line 2417

class ReverseGeocodeRequest < Struct.new(
  :query_position,
  :query_radius,
  :max_results,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key,
  :heading,
  :address_names_mode)
  SENSITIVE = [:query_position, :query_radius, :political_view, :key, :heading]
  include Aws::Structure
end