Class: Aws::GeoPlaces::Types::ReverseGeocodeResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::ReverseGeocodeResultItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
The returned location from the ‘Reverse Geocode` action.
Constant Summary collapse
- SENSITIVE =
[:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view]
Instance Attribute Summary collapse
-
#access_points ⇒ Array<Types::AccessPoint>
Position of the access point in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#address ⇒ Types::Address
The place’s address.
-
#address_number_corrected ⇒ Boolean
Boolean indicating if the address provided has been corrected.
-
#categories ⇒ Array<Types::Category>
Categories of results that results must belong to.
-
#distance ⇒ Integer
The distance in meters from the QueryPosition.
-
#food_types ⇒ Array<Types::FoodType>
List of food types offered by this result.
-
#intersections ⇒ Array<Types::Intersection>
All Intersections that are near the provided address.
-
#map_view ⇒ Array<Float>
The bounding box enclosing the geometric shape (area or line) that an individual result covers.
-
#place_id ⇒ String
The ‘PlaceId` of the place you wish to receive the information for.
-
#place_type ⇒ String
A ‘PlaceType` is a category that the result place must belong to.
-
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country.
-
#position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#postal_code_details ⇒ Array<Types::PostalCodeDetails>
Contains details about the postal code of the place/result.
-
#time_zone ⇒ Types::TimeZone
The time zone in which the place is located.
-
#title ⇒ String
The localized display name of this result item based on request parameter ‘language`.
Instance Attribute Details
#access_points ⇒ Array<Types::AccessPoint>
Position of the access point in World Geodetic System (WGS 84) format: [longitude, latitude]. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#address ⇒ Types::Address
The place’s address.
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#address_number_corrected ⇒ Boolean
Boolean indicating if the address provided has been corrected. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#categories ⇒ Array<Types::Category>
Categories of results that results must belong to.
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#distance ⇒ Integer
The distance in meters from the QueryPosition.
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#food_types ⇒ Array<Types::FoodType>
List of food types offered by this result. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#intersections ⇒ Array<Types::Intersection>
All Intersections that are near the provided address. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#map_view ⇒ Array<Float>
The bounding box enclosing the geometric shape (area or line) that an individual result covers.
The bounding box formed is defined as a set 4 coordinates: ‘[lng, lat, lng, lat]`
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#place_id ⇒ String
The ‘PlaceId` of the place you wish to receive the information for.
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#place_type ⇒ String
A ‘PlaceType` is a category that the result place must belong to.
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude].
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#postal_code_details ⇒ Array<Types::PostalCodeDetails>
Contains details about the postal code of the place/result. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#time_zone ⇒ Types::TimeZone
The time zone in which the place is located.
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#title ⇒ String
The localized display name of this result item based on request parameter ‘language`.
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2406 class ReverseGeocodeResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :postal_code_details, :position, :distance, :map_view, :categories, :food_types, :access_points, :time_zone, :political_view, :intersections) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view] include Aws::Structure end |