Class: Aws::GeoPlaces::Types::SearchNearbyResultItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

The search results of nearby places.

Constant Summary collapse

SENSITIVE =
[:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]

Instance Attribute Summary collapse

Instance Attribute Details

#access_pointsArray<Types::AccessPoint>

Position of the access point in World Geodetic System (WGS 84) format: [longitude, latitude].

Returns:



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#access_restrictionsArray<Types::AccessRestriction>

Indicates known access restrictions on a vehicle access point. The index correlates to an access point and indicates if access through this point has some form of restriction.

Returns:



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#addressTypes::Address

The place's address.

Returns:



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#address_number_correctedBoolean

Boolean indicating if the address provided has been corrected.

Returns:

  • (Boolean)


2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#business_chainsArray<Types::BusinessChain>

The Business Chains associated with the place.

Returns:



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#categoriesArray<Types::Category>

Categories of results that results must belong to.

Returns:



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#contactsTypes::Contacts

List of potential contact methods for the result/place.

Returns:



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#cross_referencesArray<Types::CrossReference>

The list of supplier references available for this place. Requires the CrossReferences additional feature to be enabled.

Returns:



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#distanceInteger

The distance in meters from the QueryPosition.

Returns:

  • (Integer)


2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#food_typesArray<Types::FoodType>

List of food types offered by this result.

Returns:



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#map_viewArray<Float>

The bounding box enclosing the geometric shape (area or line) that an individual result covers.

The bounding box formed is defined as a set 4 coordinates: [{westward lng}, {southern lat}, {eastward lng}, {northern lat}]

Returns:

  • (Array<Float>)


2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#opening_hoursArray<Types::OpeningHours>

List of opening hours objects.

Returns:



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#phonemesTypes::PhonemeDetails

How the various components of the result's address are pronounced in various languages.



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#place_attributesArray<String>

A list of place attributes for the result, such as whether the business offers drive-through service.

Returns:

  • (Array<String>)


2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#place_idString

The PlaceId of the place you wish to receive the information for.

Returns:

  • (String)


2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#place_typeString

A PlaceType is a category that the result place must belong to.

Returns:

  • (String)


2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#political_viewString

The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country.

Returns:

  • (String)


2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#positionArray<Float>

The position in World Geodetic System (WGS 84) format: [longitude, latitude].

Returns:

  • (Array<Float>)


2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#time_zoneTypes::TimeZone

The time zone in which the place is located.

Returns:



2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end

#titleString

The item's title.

Returns:

  • (String)


2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879

class SearchNearbyResultItem < Struct.new(
  :place_id,
  :place_type,
  :title,
  :address,
  :address_number_corrected,
  :position,
  :distance,
  :map_view,
  :categories,
  :food_types,
  :business_chains,
  :contacts,
  :opening_hours,
  :access_points,
  :access_restrictions,
  :time_zone,
  :political_view,
  :phonemes,
  :place_attributes,
  :cross_references)
  SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
  include Aws::Structure
end