Class: Aws::GeoPlaces::Types::SearchTextRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:query_text, :query_id, :bias_position, :political_view, :key]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_featuresArray<String>

A list of optional additional parameters, such as time zone, that can be requested for each result. For GrabMaps customers, ap-southeast-1 and ap-southeast-5 regions support only the TimeZone value.

Returns:

  • (Array<String>)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#bias_positionArray<Float>

The position, in longitude and latitude, that the results should be close to. Typically, place results returned are ranked higher the closer they are to this position. Stored in [lng, lat] and in the WGS 84 format.

Exactly one of the following fields must be set: BiasPosition, Filter.BoundingBox, or Filter.Circle.

Returns:

  • (Array<Float>)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#filterTypes::SearchTextFilter

A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.



3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#intended_useString

Indicates if the query results will be persisted in customer infrastructure. Defaults to SingleUse (not stored).

When storing SearchText responses, you must set this field to Storage to comply with the terms of service. These requests will be charged at a higher rate. Please review the user agreement and service pricing structure to determine the correct setting for your use case.

Returns:

  • (String)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#keyString

Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.

Returns:

  • (String)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#languageString

A list of BCP 47 compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry. For GrabMaps customers, ap-southeast-1 and ap-southeast-5 regions support only the following codes: en, id, km, lo, ms, my, pt, th, tl, vi, zh

Returns:

  • (String)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#max_resultsInteger

An optional limit for the number of results returned in a single call.

Default value: 20

Returns:

  • (Integer)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#next_tokenString

If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page.

Returns:

  • (String)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#political_viewString

The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Returns:

  • (String)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#query_idString

The query Id returned by the suggest API. If passed in the request, the SearchText API will preform a SearchText query with the improved query terms for the original query made to the suggest API. Not available in ap-southeast-1 and ap-southeast-5 regions for GrabMaps customers.

Exactly one of the following fields must be set: QueryText or QueryId.

Returns:

  • (String)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#query_textString

The free-form text query to match addresses against. This is usually a partially typed address from an end user in an address box or form.

Exactly one of the following fields must be set: QueryText or QueryId.

Returns:

  • (String)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end

#travel_modeString

Indicates the mode of mobility used by the end user. This is used to improve the relevance of search results. Valid values are Car, Scooter, and Truck.

Returns:

  • (String)


3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
# File 'lib/aws-sdk-geoplaces/types.rb', line 3060

class SearchTextRequest < Struct.new(
  :query_text,
  :query_id,
  :max_results,
  :bias_position,
  :filter,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :next_token,
  :travel_mode,
  :key)
  SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key]
  include Aws::Structure
end