Class: Aws::GeoPlaces::Types::StreetComponents
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::StreetComponents
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Components of a street.
Constant Summary collapse
- SENSITIVE =
[:base_name, :type, :prefix, :suffix, :direction]
Instance Attribute Summary collapse
-
#base_name ⇒ String
Base name part of the street name.
-
#direction ⇒ String
Indicates the official directional identifiers assigned to highways.
-
#language ⇒ String
A [BCP 47][1] compliant language codes for the results to be rendered in.
-
#prefix ⇒ String
A prefix is a directional identifier that precedes, but is not included in, the base name of a road.
-
#suffix ⇒ String
A suffix is a directional identifier that follows, but is not included in, the base name of a road.
-
#type ⇒ String
Street type part of the street name.
-
#type_placement ⇒ String
Defines if the street type is before or after the base name.
-
#type_separator ⇒ String
Defines a separator character such as
""or" "between the base name and type.
Instance Attribute Details
#base_name ⇒ String
Base name part of the street name.
Example: Younge from the "Younge street".
3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3325 class StreetComponents < Struct.new( :base_name, :type, :type_placement, :type_separator, :prefix, :suffix, :direction, :language) SENSITIVE = [:base_name, :type, :prefix, :suffix, :direction] include Aws::Structure end |
#direction ⇒ String
Indicates the official directional identifiers assigned to highways.
3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3325 class StreetComponents < Struct.new( :base_name, :type, :type_placement, :type_separator, :prefix, :suffix, :direction, :language) SENSITIVE = [:base_name, :type, :prefix, :suffix, :direction] include Aws::Structure end |
#language ⇒ String
A BCP 47 compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry.
3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3325 class StreetComponents < Struct.new( :base_name, :type, :type_placement, :type_separator, :prefix, :suffix, :direction, :language) SENSITIVE = [:base_name, :type, :prefix, :suffix, :direction] include Aws::Structure end |
#prefix ⇒ String
A prefix is a directional identifier that precedes, but is not included in, the base name of a road.
Example: E for East.
3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3325 class StreetComponents < Struct.new( :base_name, :type, :type_placement, :type_separator, :prefix, :suffix, :direction, :language) SENSITIVE = [:base_name, :type, :prefix, :suffix, :direction] include Aws::Structure end |
#suffix ⇒ String
A suffix is a directional identifier that follows, but is not included in, the base name of a road.
Example W for West.
3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3325 class StreetComponents < Struct.new( :base_name, :type, :type_placement, :type_separator, :prefix, :suffix, :direction, :language) SENSITIVE = [:base_name, :type, :prefix, :suffix, :direction] include Aws::Structure end |
#type ⇒ String
Street type part of the street name.
Example: "avenue".
3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3325 class StreetComponents < Struct.new( :base_name, :type, :type_placement, :type_separator, :prefix, :suffix, :direction, :language) SENSITIVE = [:base_name, :type, :prefix, :suffix, :direction] include Aws::Structure end |
#type_placement ⇒ String
Defines if the street type is before or after the base name.
3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3325 class StreetComponents < Struct.new( :base_name, :type, :type_placement, :type_separator, :prefix, :suffix, :direction, :language) SENSITIVE = [:base_name, :type, :prefix, :suffix, :direction] include Aws::Structure end |
#type_separator ⇒ String
Defines a separator character such as "" or " " between the base
name and type.
3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3325 class StreetComponents < Struct.new( :base_name, :type, :type_placement, :type_separator, :prefix, :suffix, :direction, :language) SENSITIVE = [:base_name, :type, :prefix, :suffix, :direction] include Aws::Structure end |