Class: Aws::GeoPlaces::Types::SuggestAddressHighlights

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

Describes how the parts of the textQuery matched the input query by returning the sections of the response which matched to textQuery terms.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#labelArray<Types::Highlight>

Indicates the starting and ending indexes of the places in the result which were identified to match the textQuery. This result is useful for providing emphasis to results where the user query directly matched to make selecting the correct result from a list easier for an end user.

Returns:



3399
3400
3401
3402
3403
# File 'lib/aws-sdk-geoplaces/types.rb', line 3399

class SuggestAddressHighlights < Struct.new(
  :label)
  SENSITIVE = []
  include Aws::Structure
end