Class: Aws::GeoPlaces::Types::SuggestQueryResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::SuggestQueryResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
The suggested query results.
Constant Summary collapse
- SENSITIVE =
[:query_id]
Instance Attribute Summary collapse
-
#query_id ⇒ String
QueryId can be used to complete a follow up query through the SearchText API.
-
#query_type ⇒ String
The query type.
Instance Attribute Details
#query_id ⇒ String
QueryId can be used to complete a follow up query through the
SearchText API. The QueryId retains context from the original
Suggest request such as filters, political view and language. See
the SearchText API documentation for more details SearchText API
docs. Not supported in ap-southeast-1 and ap-southeast-5
regions for GrabMaps customers.
QueryText, and QueryID are mutually exclusive.
3628 3629 3630 3631 3632 3633 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3628 class SuggestQueryResult < Struct.new( :query_id, :query_type) SENSITIVE = [:query_id] include Aws::Structure end |
#query_type ⇒ String
The query type. Category queries will search for places which have
an entry matching the given category, for example "doctor office".
BusinessChain queries will search for instances of a given business.
Not supported in ap-southeast-1 and ap-southeast-5 regions for
GrabMaps customers.
3628 3629 3630 3631 3632 3633 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3628 class SuggestQueryResult < Struct.new( :query_id, :query_type) SENSITIVE = [:query_id] include Aws::Structure end |