Class: Aws::GeoPlaces::Types::SuggestResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::SuggestResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pricing_bucket ⇒ String
The pricing bucket for which the query is charged at.
-
#query_refinements ⇒ Array<Types::QueryRefinement>
Maximum number of query terms to be returned for use with a search text query.
-
#result_items ⇒ Array<Types::SuggestResultItem>
List of places or results returned for a query.
Instance Attribute Details
#pricing_bucket ⇒ String
The pricing bucket for which the query is charged at.
For more information on pricing, please visit [Amazon Location Service Pricing].
3553 3554 3555 3556 3557 3558 3559 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3553 class SuggestResponse < Struct.new( :pricing_bucket, :result_items, :query_refinements) SENSITIVE = [] include Aws::Structure end |
#query_refinements ⇒ Array<Types::QueryRefinement>
Maximum number of query terms to be returned for use with a search text query. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
3553 3554 3555 3556 3557 3558 3559 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3553 class SuggestResponse < Struct.new( :pricing_bucket, :result_items, :query_refinements) SENSITIVE = [] include Aws::Structure end |
#result_items ⇒ Array<Types::SuggestResultItem>
List of places or results returned for a query.
3553 3554 3555 3556 3557 3558 3559 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3553 class SuggestResponse < Struct.new( :pricing_bucket, :result_items, :query_refinements) SENSITIVE = [] include Aws::Structure end |