Class: Aws::GeoPlaces::Types::SuggestResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::SuggestResultItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
The resulting item from the suggested query.
Constant Summary collapse
- SENSITIVE =
[:title]
Instance Attribute Summary collapse
-
#highlights ⇒ Types::SuggestHighlights
Describes how the parts of the response element matched the input query by returning the sections of the response which matched to input query terms.
-
#place ⇒ Types::SuggestPlaceResult
The suggested place by its unique ID.
-
#query ⇒ Types::SuggestQueryResult
The suggested query results.
-
#suggest_result_item_type ⇒ String
The result type.
-
#title ⇒ String
The display title that should be used when presenting this option to the end user.
Instance Attribute Details
#highlights ⇒ Types::SuggestHighlights
Describes how the parts of the response element matched the input query by returning the sections of the response which matched to input query terms.
3815 3816 3817 3818 3819 3820 3821 3822 3823 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3815 class SuggestResultItem < Struct.new( :title, :suggest_result_item_type, :place, :query, :highlights) SENSITIVE = [:title] include Aws::Structure end |
#place ⇒ Types::SuggestPlaceResult
The suggested place by its unique ID.
3815 3816 3817 3818 3819 3820 3821 3822 3823 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3815 class SuggestResultItem < Struct.new( :title, :suggest_result_item_type, :place, :query, :highlights) SENSITIVE = [:title] include Aws::Structure end |
#query ⇒ Types::SuggestQueryResult
The suggested query results.
3815 3816 3817 3818 3819 3820 3821 3822 3823 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3815 class SuggestResultItem < Struct.new( :title, :suggest_result_item_type, :place, :query, :highlights) SENSITIVE = [:title] include Aws::Structure end |
#suggest_result_item_type ⇒ String
The result type. Place results represent the final result for a point of interest, Query results represent a follow up query which can be completed through the SearchText operation.
3815 3816 3817 3818 3819 3820 3821 3822 3823 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3815 class SuggestResultItem < Struct.new( :title, :suggest_result_item_type, :place, :query, :highlights) SENSITIVE = [:title] include Aws::Structure end |
#title ⇒ String
The display title that should be used when presenting this option to the end user.
3815 3816 3817 3818 3819 3820 3821 3822 3823 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3815 class SuggestResultItem < Struct.new( :title, :suggest_result_item_type, :place, :query, :highlights) SENSITIVE = [:title] include Aws::Structure end |