Class: Aws::GeoPlaces::Types::TranslationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::TranslationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Translation details for the address, including alternative names and translations in available languages.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#district ⇒ Array<Types::AdminNames>
A list of administrative names and translations for the district address component.
-
#locality ⇒ Array<Types::AdminNames>
A list of administrative names and translations for the locality address component.
-
#region ⇒ Array<Types::AdminNames>
A list of administrative names and translations for the region address component.
-
#sub_region ⇒ Array<Types::AdminNames>
A list of administrative names and translations for the sub-region address component.
Instance Attribute Details
#district ⇒ Array<Types::AdminNames>
A list of administrative names and translations for the district address component.
3887 3888 3889 3890 3891 3892 3893 3894 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3887 class TranslationDetails < Struct.new( :locality, :region, :district, :sub_region) SENSITIVE = [] include Aws::Structure end |
#locality ⇒ Array<Types::AdminNames>
A list of administrative names and translations for the locality address component.
3887 3888 3889 3890 3891 3892 3893 3894 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3887 class TranslationDetails < Struct.new( :locality, :region, :district, :sub_region) SENSITIVE = [] include Aws::Structure end |
#region ⇒ Array<Types::AdminNames>
A list of administrative names and translations for the region address component.
3887 3888 3889 3890 3891 3892 3893 3894 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3887 class TranslationDetails < Struct.new( :locality, :region, :district, :sub_region) SENSITIVE = [] include Aws::Structure end |
#sub_region ⇒ Array<Types::AdminNames>
A list of administrative names and translations for the sub-region address component.
3887 3888 3889 3890 3891 3892 3893 3894 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3887 class TranslationDetails < Struct.new( :locality, :region, :district, :sub_region) SENSITIVE = [] include Aws::Structure end |