Class: Aws::GeoPlaces::Types::TranslationName

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

A translation or alternative name for an address component.

Constant Summary collapse

SENSITIVE =
[:value, :primary, :transliterated]

Instance Attribute Summary collapse

Instance Attribute Details

#languageString

A BCP 47 compliant language code for the translation name.

Returns:

  • (String)


3927
3928
3929
3930
3931
3932
3933
3934
3935
# File 'lib/aws-sdk-geoplaces/types.rb', line 3927

class TranslationName < Struct.new(
  :value,
  :language,
  :type,
  :primary,
  :transliterated)
  SENSITIVE = [:value, :primary, :transliterated]
  include Aws::Structure
end

#primaryBoolean

If true, indicates this is the primary name variant for the given language.

Returns:

  • (Boolean)


3927
3928
3929
3930
3931
3932
3933
3934
3935
# File 'lib/aws-sdk-geoplaces/types.rb', line 3927

class TranslationName < Struct.new(
  :value,
  :language,
  :type,
  :primary,
  :transliterated)
  SENSITIVE = [:value, :primary, :transliterated]
  include Aws::Structure
end

#transliteratedBoolean

If true, indicates this name is a transliterated version rather than a native script translation.

Returns:

  • (Boolean)


3927
3928
3929
3930
3931
3932
3933
3934
3935
# File 'lib/aws-sdk-geoplaces/types.rb', line 3927

class TranslationName < Struct.new(
  :value,
  :language,
  :type,
  :primary,
  :transliterated)
  SENSITIVE = [:value, :primary, :transliterated]
  include Aws::Structure
end

#typeString

The type of translation name. Valid values are Abbreviation, AreaCode, BaseName, Exonym, Shortened, and Synonym.

Returns:

  • (String)


3927
3928
3929
3930
3931
3932
3933
3934
3935
# File 'lib/aws-sdk-geoplaces/types.rb', line 3927

class TranslationName < Struct.new(
  :value,
  :language,
  :type,
  :primary,
  :transliterated)
  SENSITIVE = [:value, :primary, :transliterated]
  include Aws::Structure
end

#valueString

The translated or alternative name value.

Returns:

  • (String)


3927
3928
3929
3930
3931
3932
3933
3934
3935
# File 'lib/aws-sdk-geoplaces/types.rb', line 3927

class TranslationName < Struct.new(
  :value,
  :language,
  :type,
  :primary,
  :transliterated)
  SENSITIVE = [:value, :primary, :transliterated]
  include Aws::Structure
end