Class: Aws::GeoPlaces::Types::AccessPoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::AccessPoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Position of the access point represented by longitude and latitude for a vehicle.
Constant Summary collapse
- SENSITIVE =
[:position, :primary, :label]
Instance Attribute Summary collapse
-
#label ⇒ String
A short textual description of the access point, such as
"North Entrance". -
#position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#primary ⇒ Boolean
Set to
truefor the primary access position when the place has more than one access point. -
#type ⇒ String
The type of access point, indicating its intended use.
Instance Attribute Details
#label ⇒ String
A short textual description of the access point, such as "North Entrance".
51 52 53 54 55 56 57 58 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 51 class AccessPoint < Struct.new( :position, :type, :primary, :label) SENSITIVE = [:position, :primary, :label] include Aws::Structure end |
#position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude].
51 52 53 54 55 56 57 58 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 51 class AccessPoint < Struct.new( :position, :type, :primary, :label) SENSITIVE = [:position, :primary, :label] include Aws::Structure end |
#primary ⇒ Boolean
Set to true for the primary access position when the place has
more than one access point.
51 52 53 54 55 56 57 58 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 51 class AccessPoint < Struct.new( :position, :type, :primary, :label) SENSITIVE = [:position, :primary, :label] include Aws::Structure end |
#type ⇒ String
The type of access point, indicating its intended use. Only applies to results of type place.
51 52 53 54 55 56 57 58 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 51 class AccessPoint < Struct.new( :position, :type, :primary, :label) SENSITIVE = [:position, :primary, :label] include Aws::Structure end |