Class: Aws::GeoPlaces::Types::Address

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

The place address.

Constant Summary collapse

SENSITIVE =
[:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]

Instance Attribute Summary collapse

Instance Attribute Details

#address_numberString

The number that identifies an address within a street.

Returns:

  • (String)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#blockString

Name of the block. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

Example: ‘Sunny Mansion 203 block: 2 Chome`

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#buildingString

The name of the building at the address. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#countryTypes::Country

The country component of the address.

Returns:



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#districtString

The district or division of a locality associated with this address.

Returns:

  • (String)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#intersectionArray<String>

Name of the streets in the intersection. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

Example: ‘[“Friedrichstraße”,“Unter den Linden”]`

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (Array<String>)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#labelString

Assembled address value built out of the address components, according to the regional postal rules. This is the correctly formatted address.

Returns:

  • (String)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#localityString

The city or locality of the address.

Example: ‘Vancouver`.

Returns:

  • (String)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#postal_codeString

An alphanumeric string included in a postal address to facilitate mail sorting, such as post code, postcode, or ZIP code, for which the result should possess.

Returns:

  • (String)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#regionTypes::Region

The region or state results should be present in.

Example: ‘North Rhine-Westphalia`.

Returns:



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#secondary_address_componentsArray<Types::SecondaryAddressComponent>

Components that correspond to secondary identifiers on an Address. Secondary address components include information such as Suite or Unit Number, Building, or Floor. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

<note markdown=“1”> Coverage for ‘Address.SecondaryAddressComponents` is available in the following countries:

AUS, CAN, NZL, USA, PRI

</note>

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#streetString

The name of the street results should be present in.

Returns:

  • (String)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#street_componentsArray<Types::StreetComponents>

Components of the street. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

Example: Yonge from “Yonge street”.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#sub_blockString

Name of sub-block. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

Example: ‘Sunny Mansion 203 sub-block: 4`

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#sub_districtString

A subdivision of a district.

Example: ‘Minden-Lübbecke`.

Returns:

  • (String)


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end

#sub_regionTypes::SubRegion

The sub-region or county for which results should be present in.

Returns:



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-geoplaces/types.rb', line 190

class Address < Struct.new(
  :label,
  :country,
  :region,
  :sub_region,
  :locality,
  :district,
  :sub_district,
  :postal_code,
  :block,
  :sub_block,
  :intersection,
  :street,
  :street_components,
  :address_number,
  :building,
  :secondary_address_components)
  SENSITIVE = [:label, :locality, :district, :sub_district, :postal_code, :block, :sub_block, :street, :address_number, :building]
  include Aws::Structure
end