Class: Aws::GeoPlaces::Types::AutocompleteResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::AutocompleteResultItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
A result matching the input query text.
Constant Summary collapse
- SENSITIVE =
[:place_id, :place_type, :title, :distance, :political_view, :estimated_point_address]
Instance Attribute Summary collapse
-
#address ⇒ Types::Address
The address associated with this result.
-
#distance ⇒ Integer
The distance in meters between the center of the search area and this result.
-
#estimated_point_address ⇒ Boolean
If
true, indicates that the coordinates of the position and access points of the point address are estimated. -
#highlights ⇒ Types::AutocompleteHighlights
Indicates the starting and ending index of the place in the text query that match the found title.
-
#language ⇒ String
A list of [BCP 47][1] compliant language codes for the results to be rendered in.
-
#place_id ⇒ String
The PlaceId of the place associated with this result.
-
#place_type ⇒ String
PlaceType describes the type of result entry returned.
-
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country.
-
#title ⇒ String
A formatted string for display when presenting this result to an end user.
Instance Attribute Details
#address ⇒ Types::Address
The address associated with this result.
774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 774 class AutocompleteResultItem < Struct.new( :place_id, :place_type, :title, :address, :distance, :language, :political_view, :highlights, :estimated_point_address) SENSITIVE = [:place_id, :place_type, :title, :distance, :political_view, :estimated_point_address] include Aws::Structure end |
#distance ⇒ Integer
The distance in meters between the center of the search area and this result. Useful to evaluate how far away from the original bias position the result is.
774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 774 class AutocompleteResultItem < Struct.new( :place_id, :place_type, :title, :address, :distance, :language, :political_view, :highlights, :estimated_point_address) SENSITIVE = [:place_id, :place_type, :title, :distance, :political_view, :estimated_point_address] include Aws::Structure end |
#estimated_point_address ⇒ Boolean
If true, indicates that the coordinates of the position and access
points of the point address are estimated.
774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 774 class AutocompleteResultItem < Struct.new( :place_id, :place_type, :title, :address, :distance, :language, :political_view, :highlights, :estimated_point_address) SENSITIVE = [:place_id, :place_type, :title, :distance, :political_view, :estimated_point_address] include Aws::Structure end |
#highlights ⇒ Types::AutocompleteHighlights
Indicates the starting and ending index of the place in the text query that match the found title.
774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 774 class AutocompleteResultItem < Struct.new( :place_id, :place_type, :title, :address, :distance, :language, :political_view, :highlights, :estimated_point_address) SENSITIVE = [:place_id, :place_type, :title, :distance, :political_view, :estimated_point_address] include Aws::Structure end |
#language ⇒ String
A list of BCP 47 compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry.
774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 774 class AutocompleteResultItem < Struct.new( :place_id, :place_type, :title, :address, :distance, :language, :political_view, :highlights, :estimated_point_address) SENSITIVE = [:place_id, :place_type, :title, :distance, :political_view, :estimated_point_address] include Aws::Structure end |
#place_id ⇒ String
The PlaceId of the place associated with this result. This can be used to look up additional details about the result via GetPlace.
774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 774 class AutocompleteResultItem < Struct.new( :place_id, :place_type, :title, :address, :distance, :language, :political_view, :highlights, :estimated_point_address) SENSITIVE = [:place_id, :place_type, :title, :distance, :political_view, :estimated_point_address] include Aws::Structure end |
#place_type ⇒ String
PlaceType describes the type of result entry returned.
774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 774 class AutocompleteResultItem < Struct.new( :place_id, :place_type, :title, :address, :distance, :language, :political_view, :highlights, :estimated_point_address) SENSITIVE = [:place_id, :place_type, :title, :distance, :political_view, :estimated_point_address] include Aws::Structure end |
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country.
774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 774 class AutocompleteResultItem < Struct.new( :place_id, :place_type, :title, :address, :distance, :language, :political_view, :highlights, :estimated_point_address) SENSITIVE = [:place_id, :place_type, :title, :distance, :political_view, :estimated_point_address] include Aws::Structure end |
#title ⇒ String
A formatted string for display when presenting this result to an end user.
774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 774 class AutocompleteResultItem < Struct.new( :place_id, :place_type, :title, :address, :distance, :language, :political_view, :highlights, :estimated_point_address) SENSITIVE = [:place_id, :place_type, :title, :distance, :political_view, :estimated_point_address] include Aws::Structure end |