Class: Aws::GeoPlaces::Types::CrossReference
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::CrossReference
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
A reference to a third-party supplier's identifier for a place, enabling correlation of places across external systems.
Constant Summary collapse
- SENSITIVE =
[:source, :source_place_id]
Instance Attribute Summary collapse
-
#source ⇒ String
The name of the third-party data supplier (for example,
YelporTripAdvisor). -
#source_categories ⇒ Array<Types::Category>
The list of place category identifiers this supplier reference relates to.
-
#source_place_id ⇒ String
The place identifier assigned by the third-party supplier.
Instance Attribute Details
#source ⇒ String
The name of the third-party data supplier (for example, Yelp or
TripAdvisor).
980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 980 class CrossReference < Struct.new( :source, :source_place_id, :source_categories) SENSITIVE = [:source, :source_place_id] include Aws::Structure end |
#source_categories ⇒ Array<Types::Category>
The list of place category identifiers this supplier reference relates to.
980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 980 class CrossReference < Struct.new( :source, :source_place_id, :source_categories) SENSITIVE = [:source, :source_place_id] include Aws::Structure end |
#source_place_id ⇒ String
The place identifier assigned by the third-party supplier.
980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 980 class CrossReference < Struct.new( :source, :source_place_id, :source_categories) SENSITIVE = [:source, :source_place_id] include Aws::Structure end |