Class: Aws::GeoPlaces::Types::GeocodeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::GeocodeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pricing_bucket ⇒ String
The pricing bucket for which the query is charged at, or the maximum pricing bucket when the query is charged per item within the query.
-
#result_items ⇒ Array<Types::GeocodeResultItem>
List of places or results returned for a query.
Instance Attribute Details
#pricing_bucket ⇒ String
The pricing bucket for which the query is charged at, or the maximum pricing bucket when the query is charged per item within the query.
For more information on pricing, please visit Amazon Location Service Pricing.
1384 1385 1386 1387 1388 1389 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1384 class GeocodeResponse < Struct.new( :pricing_bucket, :result_items) SENSITIVE = [] include Aws::Structure end |
#result_items ⇒ Array<Types::GeocodeResultItem>
List of places or results returned for a query.
1384 1385 1386 1387 1388 1389 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1384 class GeocodeResponse < Struct.new( :pricing_bucket, :result_items) SENSITIVE = [] include Aws::Structure end |