Class: Aws::GeoPlaces::Types::GetPlaceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::GetPlaceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:place_id, :political_view, :key]
Instance Attribute Summary collapse
-
#additional_features ⇒ Array<String>
A list of optional additional parameters such as time zone that can be requested for each result.
-
#address_names_mode ⇒ String
Specifies how address names are returned.
-
#intended_use ⇒ String
Indicates if the query results will be persisted in customer infrastructure.
-
#key ⇒ String
Optional: The API key to be used for authorization.
-
#language ⇒ String
A list of [BCP 47][1] compliant language codes for the results to be rendered in.
-
#place_id ⇒ String
The
PlaceIdof the place you wish to receive the information for. -
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country.
Instance Attribute Details
#additional_features ⇒ Array<String>
A list of optional additional parameters such as time zone that can
be requested for each result. For GrabMaps customers,
ap-southeast-1 and ap-southeast-5 regions support only the
TimeZone value.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1601 class GetPlaceRequest < Struct.new( :place_id, :additional_features, :language, :political_view, :intended_use, :key, :address_names_mode) SENSITIVE = [:place_id, :political_view, :key] include Aws::Structure end |
#address_names_mode ⇒ String
Specifies how address names are returned. When set to
Administrative, the service returns the official administrative
names for address components. Administrative currently applies
only to addresses in the United States.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1601 class GetPlaceRequest < Struct.new( :place_id, :additional_features, :language, :political_view, :intended_use, :key, :address_names_mode) SENSITIVE = [:place_id, :political_view, :key] include Aws::Structure end |
#intended_use ⇒ String
Indicates if the query results will be persisted in customer
infrastructure. Defaults to SingleUse (not stored). Not supported
in ap-southeast-1 and ap-southeast-5 regions for GrabMaps
customers.
GetPlace responses, you must set this field to
Storage to comply with the terms of service. These requests will
be charged at a higher rate. Please review the user agreement
and service pricing structure to determine the correct setting
for your use case.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1601 class GetPlaceRequest < Struct.new( :place_id, :additional_features, :language, :political_view, :intended_use, :key, :address_names_mode) SENSITIVE = [:place_id, :political_view, :key] include Aws::Structure end |
#key ⇒ String
Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1601 class GetPlaceRequest < Struct.new( :place_id, :additional_features, :language, :political_view, :intended_use, :key, :address_names_mode) SENSITIVE = [:place_id, :political_view, :key] include Aws::Structure end |
#language ⇒ String
A list of BCP 47 compliant language codes for the results to be
rendered in. If there is no data for the result in the requested
language, data will be returned in the default language for the
entry. For GrabMaps customers, ap-southeast-1 and
ap-southeast-5 regions support only the following codes: en, id, km, lo, ms, my, pt, th, tl, vi, zh
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1601 class GetPlaceRequest < Struct.new( :place_id, :additional_features, :language, :political_view, :intended_use, :key, :address_names_mode) SENSITIVE = [:place_id, :political_view, :key] include Aws::Structure end |
#place_id ⇒ String
The PlaceId of the place you wish to receive the information for.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1601 class GetPlaceRequest < Struct.new( :place_id, :additional_features, :language, :political_view, :intended_use, :key, :address_names_mode) SENSITIVE = [:place_id, :political_view, :key] include Aws::Structure end |
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a
country. The political view applies to the results of the request to
represent unresolved territorial claims through the point of view of
the specified country. Not supported in ap-southeast-1 and
ap-southeast-5 regions for GrabMaps customers.
1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 1601 class GetPlaceRequest < Struct.new( :place_id, :additional_features, :language, :political_view, :intended_use, :key, :address_names_mode) SENSITIVE = [:place_id, :political_view, :key] include Aws::Structure end |