Class: Aws::GeoPlaces::Types::GetPlaceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:place_id, :political_view, :key]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_featuresArray<String>

A list of optional additional parameters such as time zone that can be requested for each result. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only the `TimeZone` value.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (Array<String>)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
# File 'lib/aws-sdk-geoplaces/types.rb', line 1469

class GetPlaceRequest < Struct.new(
  :place_id,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key)
  SENSITIVE = [:place_id, :political_view, :key]
  include Aws::Structure
end

#intended_useString

Indicates if the query results will be persisted in customer infrastructure. Defaults to ‘SingleUse` (not stored). Not supported in `ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

<note markdown=“1”> When storing ‘GetPlace` responses, you must set this field to `Storage` to comply with the terms of service. These requests will be charged at a higher rate. Please review the [user agreement] and [service pricing structure] to determine the correct setting for your use case.

</note>

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html [2]: aws.amazon.com/location/sla/ [3]: aws.amazon.com/location/pricing/

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
# File 'lib/aws-sdk-geoplaces/types.rb', line 1469

class GetPlaceRequest < Struct.new(
  :place_id,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key)
  SENSITIVE = [:place_id, :political_view, :key]
  include Aws::Structure
end

#keyString

Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
# File 'lib/aws-sdk-geoplaces/types.rb', line 1469

class GetPlaceRequest < Struct.new(
  :place_id,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key)
  SENSITIVE = [:place_id, :political_view, :key]
  include Aws::Structure
end

#languageString

A list of [BCP 47] compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only the following codes: `en, id, km, lo, ms, my, pt, th, tl, vi, zh`

[1]: en.wikipedia.org/wiki/IETF_language_tag [2]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
# File 'lib/aws-sdk-geoplaces/types.rb', line 1469

class GetPlaceRequest < Struct.new(
  :place_id,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key)
  SENSITIVE = [:place_id, :political_view, :key]
  include Aws::Structure
end

#place_idString

The ‘PlaceId` of the place you wish to receive the information for.

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
# File 'lib/aws-sdk-geoplaces/types.rb', line 1469

class GetPlaceRequest < Struct.new(
  :place_id,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key)
  SENSITIVE = [:place_id, :political_view, :key]
  include Aws::Structure
end

#political_viewString

The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
# File 'lib/aws-sdk-geoplaces/types.rb', line 1469

class GetPlaceRequest < Struct.new(
  :place_id,
  :additional_features,
  :language,
  :political_view,
  :intended_use,
  :key)
  SENSITIVE = [:place_id, :political_view, :key]
  include Aws::Structure
end