Class: Aws::GeoPlaces::Types::Region

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

The region or state results should be to be present in.

Example: ‘North Rhine-Westphalia`.

Constant Summary collapse

SENSITIVE =
[:code, :name]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

Abbreviated code for a the state, province or region of the country. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

Example: ‘BC`.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
# File 'lib/aws-sdk-geoplaces/types.rb', line 2068

class Region < Struct.new(
  :code,
  :name)
  SENSITIVE = [:code, :name]
  include Aws::Structure
end

#nameString

Name for a the state, province, or region of the country.

Example: ‘British Columbia`.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
# File 'lib/aws-sdk-geoplaces/types.rb', line 2068

class Region < Struct.new(
  :code,
  :name)
  SENSITIVE = [:code, :name]
  include Aws::Structure
end