Class: Aws::GeoPlaces::Types::SearchNearbyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::SearchNearbyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:query_position, :query_radius, :political_view, :key]
Instance Attribute Summary collapse
-
#additional_features ⇒ Array<String>
A list of optional additional parameters, such as time zone, that can be requested for each result.
-
#filter ⇒ Types::SearchNearbyFilter
A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.
-
#intended_use ⇒ String
Indicates if the query results will be persisted in customer infrastructure.
-
#key ⇒ String
Optional: The API key to be used for authorization.
-
#language ⇒ String
A list of [BCP 47][1] compliant language codes for the results to be rendered in.
-
#max_results ⇒ Integer
An optional limit for the number of results returned in a single call.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country.
-
#query_position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude] for which you are querying nearby results for.
-
#query_radius ⇒ Integer
The maximum distance in meters from the QueryPosition from which a result will be returned.
Instance Attribute Details
#additional_features ⇒ Array<String>
A list of optional additional parameters, such as time zone, that can be requested for each result.
2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2736 class SearchNearbyRequest < Struct.new( :query_position, :query_radius, :max_results, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_position, :query_radius, :political_view, :key] include Aws::Structure end |
#filter ⇒ Types::SearchNearbyFilter
A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.
2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2736 class SearchNearbyRequest < Struct.new( :query_position, :query_radius, :max_results, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_position, :query_radius, :political_view, :key] include Aws::Structure end |
#intended_use ⇒ String
Indicates if the query results will be persisted in customer
infrastructure. Defaults to SingleUse (not stored). Not supported
in ap-southeast-1 and ap-southeast-5 regions for GrabMaps
customers.
SearchNearby responses, you must set this field to
Storage to comply with the terms of service. These requests will
be charged at a higher rate. Please review the user agreement
and service pricing structure to determine the correct setting
for your use case.
2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2736 class SearchNearbyRequest < Struct.new( :query_position, :query_radius, :max_results, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_position, :query_radius, :political_view, :key] include Aws::Structure end |
#key ⇒ String
Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.
2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2736 class SearchNearbyRequest < Struct.new( :query_position, :query_radius, :max_results, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_position, :query_radius, :political_view, :key] include Aws::Structure end |
#language ⇒ String
A list of BCP 47 compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry.
2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2736 class SearchNearbyRequest < Struct.new( :query_position, :query_radius, :max_results, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_position, :query_radius, :political_view, :key] include Aws::Structure end |
#max_results ⇒ Integer
An optional limit for the number of results returned in a single call.
Default value: 20
2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2736 class SearchNearbyRequest < Struct.new( :query_position, :query_radius, :max_results, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_position, :query_radius, :political_view, :key] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2736 class SearchNearbyRequest < Struct.new( :query_position, :query_radius, :max_results, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_position, :query_radius, :political_view, :key] include Aws::Structure end |
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country.
2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2736 class SearchNearbyRequest < Struct.new( :query_position, :query_radius, :max_results, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_position, :query_radius, :political_view, :key] include Aws::Structure end |
#query_position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude] for which you are querying nearby results for. Results closer to the position will be ranked higher then results further away from the position
2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2736 class SearchNearbyRequest < Struct.new( :query_position, :query_radius, :max_results, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_position, :query_radius, :political_view, :key] include Aws::Structure end |
#query_radius ⇒ Integer
The maximum distance in meters from the QueryPosition from which a result will be returned.
QueryText, and QueryID are mutually exclusive.
2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2736 class SearchNearbyRequest < Struct.new( :query_position, :query_radius, :max_results, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_position, :query_radius, :political_view, :key] include Aws::Structure end |