Class: Aws::GeoPlaces::Types::SearchNearbyResultItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::SearchNearbyResultItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
The search results of nearby places.
Constant Summary collapse
- SENSITIVE =
[:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes]
Instance Attribute Summary collapse
-
#access_points ⇒ Array<Types::AccessPoint>
Position of the access point in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#access_restrictions ⇒ Array<Types::AccessRestriction>
Indicates known access restrictions on a vehicle access point.
-
#address ⇒ Types::Address
The place's address.
-
#address_number_corrected ⇒ Boolean
Boolean indicating if the address provided has been corrected.
-
#business_chains ⇒ Array<Types::BusinessChain>
The Business Chains associated with the place.
-
#categories ⇒ Array<Types::Category>
Categories of results that results must belong to.
-
#contacts ⇒ Types::Contacts
List of potential contact methods for the result/place.
-
#cross_references ⇒ Array<Types::CrossReference>
The list of supplier references available for this place.
-
#distance ⇒ Integer
The distance in meters from the QueryPosition.
-
#food_types ⇒ Array<Types::FoodType>
List of food types offered by this result.
-
#map_view ⇒ Array<Float>
The bounding box enclosing the geometric shape (area or line) that an individual result covers.
-
#opening_hours ⇒ Array<Types::OpeningHours>
List of opening hours objects.
-
#phonemes ⇒ Types::PhonemeDetails
How the various components of the result's address are pronounced in various languages.
-
#place_attributes ⇒ Array<String>
A list of place attributes for the result, such as whether the business offers drive-through service.
-
#place_id ⇒ String
The
PlaceIdof the place you wish to receive the information for. -
#place_type ⇒ String
A
PlaceTypeis a category that the result place must belong to. -
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country.
-
#position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#time_zone ⇒ Types::TimeZone
The time zone in which the place is located.
-
#title ⇒ String
The item's title.
Instance Attribute Details
#access_points ⇒ Array<Types::AccessPoint>
Position of the access point in World Geodetic System (WGS 84) format: [longitude, latitude].
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#access_restrictions ⇒ Array<Types::AccessRestriction>
Indicates known access restrictions on a vehicle access point. The index correlates to an access point and indicates if access through this point has some form of restriction.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#address ⇒ Types::Address
The place's address.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#address_number_corrected ⇒ Boolean
Boolean indicating if the address provided has been corrected.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#business_chains ⇒ Array<Types::BusinessChain>
The Business Chains associated with the place.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#categories ⇒ Array<Types::Category>
Categories of results that results must belong to.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#contacts ⇒ Types::Contacts
List of potential contact methods for the result/place.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#cross_references ⇒ Array<Types::CrossReference>
The list of supplier references available for this place. Requires
the CrossReferences additional feature to be enabled.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#distance ⇒ Integer
The distance in meters from the QueryPosition.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#food_types ⇒ Array<Types::FoodType>
List of food types offered by this result.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#map_view ⇒ Array<Float>
The bounding box enclosing the geometric shape (area or line) that an individual result covers.
The bounding box formed is defined as a set 4 coordinates:
[{westward lng}, {southern lat}, {eastward lng}, {northern lat}]
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#opening_hours ⇒ Array<Types::OpeningHours>
List of opening hours objects.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#phonemes ⇒ Types::PhonemeDetails
How the various components of the result's address are pronounced in various languages.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#place_attributes ⇒ Array<String>
A list of place attributes for the result, such as whether the business offers drive-through service.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#place_id ⇒ String
The PlaceId of the place you wish to receive the information for.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#place_type ⇒ String
A PlaceType is a category that the result place must belong to.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude].
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#time_zone ⇒ Types::TimeZone
The time zone in which the place is located.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#title ⇒ String
The item's title.
2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2879 class SearchNearbyResultItem < Struct.new( :place_id, :place_type, :title, :address, :address_number_corrected, :position, :distance, :map_view, :categories, :food_types, :business_chains, :contacts, :opening_hours, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :title, :address_number_corrected, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |