Class: Aws::GeoPlaces::Types::SearchTextRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::SearchTextRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:query_text, :query_id, :bias_position, :political_view, :key]
Instance Attribute Summary collapse
-
#additional_features ⇒ Array<String>
A list of optional additional parameters, such as time zone, that can be requested for each result.
-
#bias_position ⇒ Array<Float>
The position, in longitude and latitude, that the results should be close to.
-
#filter ⇒ Types::SearchTextFilter
A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.
-
#intended_use ⇒ String
Indicates if the query results will be persisted in customer infrastructure.
-
#key ⇒ String
Optional: The API key to be used for authorization.
-
#language ⇒ String
A list of [BCP 47] compliant language codes for the results to be rendered in.
-
#max_results ⇒ Integer
An optional limit for the number of results returned in a single call.
-
#next_token ⇒ String
If ‘nextToken` is returned, there are more results available.
-
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country.
-
#query_id ⇒ String
The query Id returned by the suggest API.
-
#query_text ⇒ String
The free-form text query to match addresses against.
Instance Attribute Details
#additional_features ⇒ Array<String>
A list of optional additional parameters, such as time zone, that can be requested for each result. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only the `TimeZone` value.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |
#bias_position ⇒ Array<Float>
The position, in longitude and latitude, that the results should be close to. Typically, place results returned are ranked higher the closer they are to this position. Stored in ‘[lng, lat]` and in the WGS 84 format.
<note markdown=“1”> Exactly one of the following fields must be set: ‘BiasPosition`, `Filter.BoundingBox`, or `Filter.Circle`.
</note>
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |
#filter ⇒ Types::SearchTextFilter
A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |
#intended_use ⇒ String
Indicates if the query results will be persisted in customer infrastructure. Defaults to ‘SingleUse` (not stored).
<note markdown=“1”> When storing ‘SearchText` responses, you must set this field to `Storage` to comply with the terms of service. These requests will be charged at a higher rate. Please review the [user agreement] and [service pricing structure] to determine the correct setting for your use case.
</note>
[1]: aws.amazon.com/location/sla/ [2]: aws.amazon.com/location/pricing/
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |
#key ⇒ String
Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |
#language ⇒ String
A list of [BCP 47] compliant language codes for the results to be rendered in. If there is no data for the result in the requested language, data will be returned in the default language for the entry. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only the following codes: `en, id, km, lo, ms, my, pt, th, tl, vi, zh`
[1]: en.wikipedia.org/wiki/IETF_language_tag [2]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |
#max_results ⇒ Integer
An optional limit for the number of results returned in a single call.
Default value: 20
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |
#next_token ⇒ String
If ‘nextToken` is returned, there are more results available. The value of `nextToken` is a unique pagination token for each page.
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |
#query_id ⇒ String
The query Id returned by the suggest API. If passed in the request, the SearchText API will preform a SearchText query with the improved query terms for the original query made to the suggest API. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
<note markdown=“1”> Exactly one of the following fields must be set: ‘QueryText` or `QueryId`.
</note>
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |
#query_text ⇒ String
The free-form text query to match addresses against. This is usually a partially typed address from an end user in an address box or form.
<note markdown=“1”> Exactly one of the following fields must be set: ‘QueryText` or `QueryId`.
</note>
2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 2872 class SearchTextRequest < Struct.new( :query_text, :query_id, :max_results, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :next_token, :key) SENSITIVE = [:query_text, :query_id, :bias_position, :political_view, :key] include Aws::Structure end |