Class: Aws::GeoPlaces::Types::SuggestPlaceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::SuggestPlaceResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
The suggested place results.
Constant Summary collapse
- SENSITIVE =
[:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes]
Instance Attribute Summary collapse
-
#access_points ⇒ Array<Types::AccessPoint>
Position of the access point in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#access_restrictions ⇒ Array<Types::AccessRestriction>
Indicates known access restrictions on a vehicle access point.
-
#address ⇒ Types::Address
The place's address.
-
#business_chains ⇒ Array<Types::BusinessChain>
The Business Chains associated with the place.
-
#categories ⇒ Array<Types::Category>
Categories of results that results must belong to.
-
#cross_references ⇒ Array<Types::CrossReference>
The list of supplier references available for this place.
-
#distance ⇒ Integer
The distance in meters from the QueryPosition.
-
#food_types ⇒ Array<Types::FoodType>
List of food types offered by this result.
-
#map_view ⇒ Array<Float>
The bounding box enclosing the geometric shape (area or line) that an individual result covers.
-
#phonemes ⇒ Types::PhonemeDetails
How the various components of the result's address are pronounced in various languages.
-
#place_attributes ⇒ Array<String>
A list of place attributes for the result, such as whether the business offers drive-through service.
-
#place_id ⇒ String
The
PlaceIdof the place you wish to receive the information for. -
#place_type ⇒ String
A
PlaceTypeis a category that the result place must belong to. -
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country.
-
#position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#time_zone ⇒ Types::TimeZone
The time zone in which the place is located.
Instance Attribute Details
#access_points ⇒ Array<Types::AccessPoint>
Position of the access point in World Geodetic System (WGS 84)
format: [longitude, latitude]. Not available in ap-southeast-1
and ap-southeast-5 regions for GrabMaps customers.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#access_restrictions ⇒ Array<Types::AccessRestriction>
Indicates known access restrictions on a vehicle access point. The
index correlates to an access point and indicates if access through
this point has some form of restriction. Not available in
ap-southeast-1 and ap-southeast-5 regions for GrabMaps
customers.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#address ⇒ Types::Address
The place's address.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#business_chains ⇒ Array<Types::BusinessChain>
The Business Chains associated with the place. Not available in
ap-southeast-1 and ap-southeast-5 regions for GrabMaps
customers.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#categories ⇒ Array<Types::Category>
Categories of results that results must belong to.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#cross_references ⇒ Array<Types::CrossReference>
The list of supplier references available for this place. Requires
the CrossReferences additional feature to be enabled.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#distance ⇒ Integer
The distance in meters from the QueryPosition.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#food_types ⇒ Array<Types::FoodType>
List of food types offered by this result. Not available in
ap-southeast-1 and ap-southeast-5 regions for GrabMaps
customers.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#map_view ⇒ Array<Float>
The bounding box enclosing the geometric shape (area or line) that an individual result covers.
The bounding box formed is defined as a set 4 coordinates:
[{westward lng}, {southern lat}, {eastward lng}, {northern lat}]
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#phonemes ⇒ Types::PhonemeDetails
How the various components of the result's address are pronounced
in various languages. Not available in ap-southeast-1 and
ap-southeast-5 regions for GrabMaps customers.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#place_attributes ⇒ Array<String>
A list of place attributes for the result, such as whether the business offers drive-through service.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#place_id ⇒ String
The PlaceId of the place you wish to receive the information for.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#place_type ⇒ String
A PlaceType is a category that the result place must belong to.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a
country. The political view applies to the results of the request to
represent unresolved territorial claims through the point of view of
the specified country. Not available in ap-southeast-1 and
ap-southeast-5 regions for GrabMaps customers.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude].
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |
#time_zone ⇒ Types::TimeZone
The time zone in which the place is located.
3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3573 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes, :place_attributes, :cross_references) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view, :place_attributes] include Aws::Structure end |