Class: Aws::GeoPlaces::Types::SuggestPlaceResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::SuggestPlaceResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
The suggested place results.
Constant Summary collapse
- SENSITIVE =
[:place_id, :place_type, :position, :distance, :map_view, :political_view]
Instance Attribute Summary collapse
-
#access_points ⇒ Array<Types::AccessPoint>
Position of the access point in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#access_restrictions ⇒ Array<Types::AccessRestriction>
Indicates known access restrictions on a vehicle access point.
-
#address ⇒ Types::Address
The place’s address.
-
#business_chains ⇒ Array<Types::BusinessChain>
The Business Chains associated with the place.
-
#categories ⇒ Array<Types::Category>
Categories of results that results must belong to.
-
#distance ⇒ Integer
The distance in meters from the QueryPosition.
-
#food_types ⇒ Array<Types::FoodType>
List of food types offered by this result.
-
#map_view ⇒ Array<Float>
The bounding box enclosing the geometric shape (area or line) that an individual result covers.
-
#phonemes ⇒ Types::PhonemeDetails
How the various components of the result’s address are pronounced in various languages.
-
#place_id ⇒ String
The ‘PlaceId` of the place you wish to receive the information for.
-
#place_type ⇒ String
A ‘PlaceType` is a category that the result place must belong to.
-
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country.
-
#position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#time_zone ⇒ Types::TimeZone
The time zone in which the place is located.
Instance Attribute Details
#access_points ⇒ Array<Types::AccessPoint>
Position of the access point in World Geodetic System (WGS 84) format: [longitude, latitude]. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#access_restrictions ⇒ Array<Types::AccessRestriction>
Indicates known access restrictions on a vehicle access point. The index correlates to an access point and indicates if access through this point has some form of restriction. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#address ⇒ Types::Address
The place’s address.
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#business_chains ⇒ Array<Types::BusinessChain>
The Business Chains associated with the place. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#categories ⇒ Array<Types::Category>
Categories of results that results must belong to.
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#distance ⇒ Integer
The distance in meters from the QueryPosition.
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#food_types ⇒ Array<Types::FoodType>
List of food types offered by this result. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#map_view ⇒ Array<Float>
The bounding box enclosing the geometric shape (area or line) that an individual result covers.
The bounding box formed is defined as a set 4 coordinates: ‘[lng, lat, lng, lat]`
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#phonemes ⇒ Types::PhonemeDetails
How the various components of the result’s address are pronounced in various languages. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#place_id ⇒ String
The ‘PlaceId` of the place you wish to receive the information for.
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#place_type ⇒ String
A ‘PlaceType` is a category that the result place must belong to.
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country. The political view applies to the results of the request to represent unresolved territorial claims through the point of view of the specified country. Not available in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#position ⇒ Array<Float>
The position in World Geodetic System (WGS 84) format: [longitude, latitude].
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |
#time_zone ⇒ Types::TimeZone
The time zone in which the place is located.
3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3357 class SuggestPlaceResult < Struct.new( :place_id, :place_type, :address, :position, :distance, :map_view, :categories, :food_types, :business_chains, :access_points, :access_restrictions, :time_zone, :political_view, :phonemes) SENSITIVE = [:place_id, :place_type, :position, :distance, :map_view, :political_view] include Aws::Structure end |