Class: Aws::GeoPlaces::Types::SuggestQueryResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-geoplaces/types.rb

Overview

The suggested query results.

Constant Summary collapse

SENSITIVE =
[:query_id]

Instance Attribute Summary collapse

Instance Attribute Details

#query_idString

QueryId can be used to complete a follow up query through the SearchText API. The QueryId retains context from the original Suggest request such as filters, political view and language. See the SearchText API documentation for more details [SearchText API docs]. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

<note markdown=“1”> The fields ‘QueryText`, and `QueryID` are mutually exclusive.

</note>

[1]: docs.aws.amazon.com/location/latest/APIReference/API_geoplaces_SearchText.html [2]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


3410
3411
3412
3413
3414
3415
# File 'lib/aws-sdk-geoplaces/types.rb', line 3410

class SuggestQueryResult < Struct.new(
  :query_id,
  :query_type)
  SENSITIVE = [:query_id]
  include Aws::Structure
end

#query_typeString

The query type. Category queries will search for places which have an entry matching the given category, for example “doctor office”. BusinessChain queries will search for instances of a given business. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


3410
3411
3412
3413
3414
3415
# File 'lib/aws-sdk-geoplaces/types.rb', line 3410

class SuggestQueryResult < Struct.new(
  :query_id,
  :query_type)
  SENSITIVE = [:query_id]
  include Aws::Structure
end