Class: Aws::GeoPlaces::Types::SuggestRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::SuggestRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:query_text, :bias_position, :political_view, :key]
Instance Attribute Summary collapse
-
#additional_features ⇒ Array<String>
A list of optional additional parameters, such as time zone, that can be requested for each result.
-
#bias_position ⇒ Array<Float>
The position, in longitude and latitude, that the results should be close to.
-
#filter ⇒ Types::SuggestFilter
A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.
-
#intended_use ⇒ String
Indicates if the query results will be persisted in customer infrastructure.
-
#key ⇒ String
Optional: The API key to be used for authorization.
-
#language ⇒ String
A list of [BCP 47][1] compliant language codes for the results to be rendered in.
-
#max_query_refinements ⇒ Integer
Maximum number of query terms to be returned for use with a search text query.
-
#max_results ⇒ Integer
An optional limit for the number of results returned in a single call.
-
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a country.
-
#query_text ⇒ String
The free-form text query to match addresses against.
-
#travel_mode ⇒ String
Indicates the mode of mobility used by the end user.
Instance Attribute Details
#additional_features ⇒ Array<String>
A list of optional additional parameters, such as time zone, that
can be requested for each result. For GrabMaps customers,
ap-southeast-1 and ap-southeast-5 regions support only the
Core and TimeZone values.
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#bias_position ⇒ Array<Float>
The position, in longitude and latitude, that the results should be
close to. Typically, place results returned are ranked higher the
closer they are to this position. Stored in [lng, lat] and in the
WGS 84 format.
BiasPosition, FilterBoundingBox, and FilterCircle
are mutually exclusive.
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#filter ⇒ Types::SuggestFilter
A structure which contains a set of inclusion/exclusion properties that results must possess in order to be returned as a result.
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#intended_use ⇒ String
Indicates if the query results will be persisted in customer
infrastructure. Defaults to SingleUse (not stored). Currently,
Suggest does not support storage of results.
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#key ⇒ String
Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#language ⇒ String
A list of BCP 47 compliant language codes for the results to be
rendered in. If there is no data for the result in the requested
language, data will be returned in the default language for the
entry. For GrabMaps customers, ap-southeast-1 and
ap-southeast-5 regions support only the following codes: en, id, km, lo, ms, my, pt, th, tl, vi, zh
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#max_query_refinements ⇒ Integer
Maximum number of query terms to be returned for use with a search
text query. Not supported in ap-southeast-1 and ap-southeast-5
regions for GrabMaps customers.
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#max_results ⇒ Integer
An optional limit for the number of results returned in a single call.
Default value: 20
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#political_view ⇒ String
The alpha-2 or alpha-3 character code for the political view of a
country. The political view applies to the results of the request to
represent unresolved territorial claims through the point of view of
the specified country. Not supported in ap-southeast-1 and
ap-southeast-5 regions for GrabMaps customers.
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#query_text ⇒ String
The free-form text query to match addresses against. This is usually a partially typed address from an end user in an address box or form.
QueryText and QueryID are mutually exclusive.
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |
#travel_mode ⇒ String
Indicates the mode of mobility used by the end user. This is used to
improve the relevance of search results. Valid values are Car,
Scooter, and Truck.
3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3735 class SuggestRequest < Struct.new( :query_text, :max_results, :max_query_refinements, :bias_position, :filter, :additional_features, :language, :political_view, :intended_use, :travel_mode, :key) SENSITIVE = [:query_text, :bias_position, :political_view, :key] include Aws::Structure end |