Class: Aws::GeoPlaces::Types::TranslationName
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoPlaces::Types::TranslationName
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-geoplaces/types.rb
Overview
A translation or alternative name for an address component.
Constant Summary collapse
- SENSITIVE =
[:value, :primary, :transliterated]
Instance Attribute Summary collapse
-
#language ⇒ String
A [BCP 47][1] compliant language code for the translation name.
-
#primary ⇒ Boolean
If
true, indicates this is the primary name variant for the given language. -
#transliterated ⇒ Boolean
If
true, indicates this name is a transliterated version rather than a native script translation. -
#type ⇒ String
The type of translation name.
-
#value ⇒ String
The translated or alternative name value.
Instance Attribute Details
#language ⇒ String
A BCP 47 compliant language code for the translation name.
3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3927 class TranslationName < Struct.new( :value, :language, :type, :primary, :transliterated) SENSITIVE = [:value, :primary, :transliterated] include Aws::Structure end |
#primary ⇒ Boolean
If true, indicates this is the primary name variant for the given
language.
3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3927 class TranslationName < Struct.new( :value, :language, :type, :primary, :transliterated) SENSITIVE = [:value, :primary, :transliterated] include Aws::Structure end |
#transliterated ⇒ Boolean
If true, indicates this name is a transliterated version rather
than a native script translation.
3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3927 class TranslationName < Struct.new( :value, :language, :type, :primary, :transliterated) SENSITIVE = [:value, :primary, :transliterated] include Aws::Structure end |
#type ⇒ String
The type of translation name. Valid values are Abbreviation,
AreaCode, BaseName, Exonym, Shortened, and Synonym.
3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3927 class TranslationName < Struct.new( :value, :language, :type, :primary, :transliterated) SENSITIVE = [:value, :primary, :transliterated] include Aws::Structure end |
#value ⇒ String
The translated or alternative name value.
3927 3928 3929 3930 3931 3932 3933 3934 3935 |
# File 'lib/aws-sdk-geoplaces/types.rb', line 3927 class TranslationName < Struct.new( :value, :language, :type, :primary, :transliterated) SENSITIVE = [:value, :primary, :transliterated] include Aws::Structure end |